@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
-from django.conf import settings
+from __future__ import unicode_literals
 
-MUNICIPIOS_GEO = getattr(settings,'MUNICIPIOS_GEO', False)
+from django.conf import settings
+from django.utils.encoding import python_2_unicode_compatible
+
+MUNICIPIOS_GEO = getattr(settings, 'MUNICIPIOS_GEO', False)
 
 if MUNICIPIOS_GEO:
     from django.contrib.gis.db import models
@@ -10,10 +13,10 @@ else:
 
 SRID = None
 if MUNICIPIOS_GEO:
-    SRID = getattr(settings,'MUNICIPIOS_SRID', 900913)
-    
-    
-    
+    SRID = getattr(settings, 'MUNICIPIOS_SRID', 900913)
+
+
+@python_2_unicode_compatible
 class UF(models.Model):
     """
     Unidades Federativas (Estados) do Brasil
@@ -26,24 +29,24 @@ class UF(models.Model):
         geom = models.MultiPolygonField(srid=SRID, null=True, blank=True)
         objects = models.GeoManager()
 
-    def __unicode__(self):
+    def __str__(self):
         return self.nome
-    
-         
+
+
+@python_2_unicode_compatible
 class Municipio(models.Model):
     """
     Municípios do Brasil
     """
     id_ibge = models.IntegerField(primary_key=True)
     nome = models.CharField(max_length=150)
-    nome_abreviado = models.CharField(max_length=150, blank=True, null=True)    
+    nome_abreviado = models.CharField(max_length=150, blank=True, null=True)
     uf = models.ForeignKey(UF)
     uf_sigla = models.CharField(max_length=2)
-    if MUNICIPIOS_GEO: 
+    if MUNICIPIOS_GEO:
         sede = models.PointField(srid=SRID, null=True, blank=True)
         geom = models.MultiPolygonField(srid=SRID, null=True, blank=True)
         objects = models.GeoManager()
-            
-    def __unicode__(self):
-        return u'%s - %s' % (self.nome, self.uf_sigla)
-    
+
+    def __str__(self):
+        return '%s - %s' % (self.nome, self.uf_sigla)
